@@ -12,11 +12,9 @@ from bert4keras.models import build_transformer_model
 from bert4keras.tokenizers import Tokenizer
 import numpy as np
 import os
-import sys
 import requests
 import zipfile
-sys.path.append(os.path.abspath('../'))
-from util import progress_bar
+from pynovice.util import progress_bar
 
 CUR_PASTH = os.path.dirname(os.path.abspath(__file__))
 
@@ -72,8 +70,8 @@ class DownloadBertModel:
         os.remove("_tmp.zip")
 
 if __name__ == '__main__':
-    aa=DownloadBertModel()
-    aa.dump()
+    # aa=DownloadBertModel()
+    # aa.dump()
     print(CUR_PASTH)
     bb=ExtractBertFeatures()
     print(bb.predict('你好啊'))
